<?php
/**
* Custom Hooks
*
* @package GridRead WordPress Theme
* @copyright Copyright (C) 2025 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridread_before_header() {
    do_action('gridread_before_header');
}
add_action('gridread_before_header', 'gridread_secondary_menu_area', 50 );

function gridread_after_header() {
    do_action('gridread_after_header');
}

function gridread_before_slider() {
    do_action('gridread_before_slider');
}

function gridread_after_slider() {
    do_action('gridread_after_slider');
}

function gridread_before_main_content() {
    do_action('gridread_before_main_content');
}
add_action('gridread_before_main_content', 'gridread_top_left_right_widgets', 20 );
add_action('gridread_before_main_content', 'gridread_top_widgets', 40 );

function gridread_after_main_content() {
    do_action('gridread_after_main_content');
}
add_action('gridread_after_main_content', 'gridread_bottom_widgets', 10 );
add_action('gridread_after_main_content', 'gridread_bottom_left_right_widgets', 40 );

function gridread_sidebar_one() {
    do_action('gridread_sidebar_one');
}
add_action('gridread_sidebar_one', 'gridread_sidebar_one_widgets', 10 );

function gridread_before_single_post() {
    do_action('gridread_before_single_post');
}

function gridread_before_single_post_title() {
    do_action('gridread_before_single_post_title');
}

function gridread_after_single_post_title() {
    do_action('gridread_after_single_post_title');
}

function gridread_top_single_post_content() {
    do_action('gridread_top_single_post_content');
}

function gridread_bottom_single_post_content() {
    do_action('gridread_bottom_single_post_content');
}

function gridread_after_single_post_content() {
    do_action('gridread_after_single_post_content');
}

function gridread_after_single_post() {
    do_action('gridread_after_single_post');
}

function gridread_before_single_page() {
    do_action('gridread_before_single_page');
}

function gridread_before_single_page_title() {
    do_action('gridread_before_single_page_title');
}

function gridread_after_single_page_title() {
    do_action('gridread_after_single_page_title');
}

function gridread_after_single_page_content() {
    do_action('gridread_after_single_page_content');
}

function gridread_after_single_page() {
    do_action('gridread_after_single_page');
}

function gridread_before_comments() {
    do_action('gridread_before_comments');
}

function gridread_after_comments() {
    do_action('gridread_after_comments');
}

function gridread_before_footer() {
    do_action('gridread_before_footer');
}

function gridread_after_footer() {
    do_action('gridread_after_footer');
}

function gridread_before_nongrid_post_title() {
    do_action('gridread_before_nongrid_post_title');
}

function gridread_after_nongrid_post_title() {
    do_action('gridread_after_nongrid_post_title');
}

if ( ! function_exists( 'gridread_remove_theme_support' ) ) :
function gridread_remove_theme_support() {
    if ( gridread_is_fitvids_active() ) {
        // Remove responsive embedded content support.
        remove_theme_support( 'responsive-embeds' );
    }
}
endif;
add_action( 'after_setup_theme', 'gridread_remove_theme_support', 1000 );